==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/sacado/example/FEApp/FEApp_ElementFactory.hpp <==
// $Id: FEApp_ElementFactory.hpp,v 1.2 2007/07/09 17:04:02 etphipp Exp $ 
// $Source: /space/CVS/Trilinos/packages/sacado/example/FEApp/FEApp_ElementFactory.hpp,v $ 
// @HEADER
// ***********************************************************************
// 
//                           Sacado Package
//                 Copyright (2006) Sandia Corporation
// 
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact David M. Gay (dmgay@sandia.gov) or Eric T. Phipps
// (etphipp@sandia.gov).
// 
// ***********************************************************************
// @HEADER

#ifndef FEAPP_ELEMENTFACTORY_HPP
#define FEAPP_ELEMENTFACTORY_HPP

#include "Teuchos_ParameterList.hpp"
#include "Teuchos_RCP.hpp"

#include "FEApp_AbstractElement.hpp"

namespace FEApp {

  /*!
   * \brief A factory class to instantiate AbstractElement objects
   */
  class ElementFactory {
  public:

    //! Default constructor
    ElementFactory(
	      const Teuchos::RCP<Teuchos::ParameterList>& elemParams);

    //! Destructor
    virtual ~ElementFactory() {}

    virtual Teuchos::RCP<FEApp::AbstractElement>
    create();

  private:

    //! Private to prohibit copying
    ElementFactory(const ElementFactory&);

    //! Private to prohibit copying
    ElementFactory& operator=(const ElementFactory&);

  protected:

    //! Parameter list specifying what element to create
    Teuchos::RCP<Teuchos::ParameterList> elemParams;

  };

}

#endif // FEAPP_ELEMENTFACTORY_HPP

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/sacado/example/FEApp/FEApp_ElementFactory.hpp <==
// $Id$ 
// $Source$ 
// @HEADER
// ***********************************************************************
// 
//                           Sacado Package
//                 Copyright (2006) Sandia Corporation
// 
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact David M. Gay (dmgay@sandia.gov) or Eric T. Phipps
// (etphipp@sandia.gov).
// 
// ***********************************************************************
// @HEADER

#ifndef FEAPP_ELEMENTFACTORY_HPP
#define FEAPP_ELEMENTFACTORY_HPP

#include "Teuchos_ParameterList.hpp"
#include "Teuchos_RCP.hpp"

#include "FEApp_AbstractElement.hpp"

namespace FEApp {

  /*!
   * \brief A factory class to instantiate AbstractElement objects
   */
  class ElementFactory {
  public:

    //! Default constructor
    ElementFactory(const Teuchos::RCP<Teuchos::ParameterList>& elemParams);

    //! Destructor
    virtual ~ElementFactory() {}

    virtual Teuchos::RCP<FEApp::AbstractElement>
    create();

  private:

    //! Private to prohibit copying
    ElementFactory(const ElementFactory&);

    //! Private to prohibit copying
    ElementFactory& operator=(const ElementFactory&);

  protected:

    //! Parameter list specifying what element to create
    Teuchos::RCP<Teuchos::ParameterList> elemParams;

  };

}

#endif // FEAPP_ELEMENTFACTORY_HPP
